@@ -70,6 +70,19 @@ pub enum LendingInstruction {
         collateral_amount: u64,
     },
 
+    // 6
+    /// Initializes a new lending market obligation.
+    ///
+    /// Accounts expected by this instruction:
+    ///
+    ///   0. `[writable]` Obligation account - uninitialized.
+    ///   1. `[]` Lending market account.
+    ///   2. `[signer]` Obligation owner.
+    ///   3. `[]` Clock sysvar.
+    ///   4. `[]` Rent sysvar.
+    ///   5. `[]` Token program id.
+    InitObligation,
+
     // 7
     /// Refresh an obligation's accrued interest and collateral and liquidity prices. Requires
     /// refreshed reserves, as all obligation collateral deposit reserves in order, followed by all
@@ -289,6 +302,7 @@ impl LendingInstruction {
                 let (collateral_amount, _rest) = Self::unpack_u64(rest)?;
                 Self::RedeemReserveCollateral { collateral_amount }
             }
+            6 => Self::InitObligation,
             7 => Self::RefreshObligation,
             8 => {
                 let (collateral_amount, _rest) = Self::unpack_u64(rest)?;
@@ -355,7 +369,9 @@ impl LendingInstruction {
                 buf.push(5);
                 buf.extend_from_slice(&collateral_amount.to_le_bytes());
             }
-
+            Self::InitObligation => {
+                buf.push(6);
+            }
             Self::RefreshObligation => {
                 buf.push(7);
             }
@@ -485,6 +501,28 @@ pub fn redeem_reserve_collateral(
     }
 }
 
+/// Creates an `InitObligation` instruction.
+#[allow(clippy::too_many_arguments)]
+pub fn init_obligation(
+    program_id: Pubkey,
+    obligation_pubkey: Pubkey,
+    lending_market_pubkey: Pubkey,
+    obligation_owner_pubkey: Pubkey,
+) -> Instruction {
+    Instruction {
+        program_id,
+        accounts: vec![
+            AccountMeta::new(obligation_pubkey, false),
+            AccountMeta::new_readonly(lending_market_pubkey, false),
+            AccountMeta::new_readonly(obligation_owner_pubkey, true),
+            AccountMeta::new_readonly(sysvar::clock::id(), false),
+            AccountMeta::new_readonly(sysvar::rent::id(), false),
+            AccountMeta::new_readonly(spl_token::id(), false),
+        ],
+        data: LendingInstruction::InitObligation.pack(),
+    }
+}
+
 /// Creates a `RefreshObligation` instruction.
 #[allow(clippy::too_many_arguments)]
 pub fn refresh_obligation(
